#!/usr/bin/python3

#	cve-manager : CVE management tool
#	Copyright (C) 2017-2022 Alexey Appolonov
#
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

import re

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Convert FSTEC version to a standard format

def ConvertFSTECVer(ver):

	# If list of versions
	search = re.search(r'[0-9][^\s]*(\sи\s[0-9][^\s]*)+', ver)
	if search:
		return re.sub(r'\s+и\s+', ', ', search.group(0))

	# If particular version
	search = re.search(r'^[0-9][^\s]*', ver)
	if search:
		return search.group(0)

	# If range of versions
	range_left  = ''
	range_right = ''
	search_range_left  = re.search(r'от\s+[0-9][^\s]*', ver)
	search_range_right = re.search(r'до\s+[0-9][^\s]*', ver)

	if search_range_left:
		range_left  = re.sub(r'от\s+', '', search_range_left.group(0))

	if search_range_right:
		range_right = re.sub(r'до\s+', '', search_range_right.group(0))

	if range_left or range_right:
		return \
			f'{"[" + range_left  if range_left  else "("};' \
			f'{range_right + "]" if range_right else ")"}'

	# Version is not stated
	return '-'
